"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.pipeSolanaLogs = void 0;
const amman_client_1 = require("@metaplex-foundation/amman-client");
const web3_js_1 = require("@solana/web3.js");
const ansi_colors_1 = __importDefault(require("ansi-colors"));
const programs_1 = require("../../diagnostics/programs");
const utils_1 = require("../../utils");
async function pipeSolanaLogs(amman, commitment) {
    const logger = new programs_1.PrettyLogger(amman);
    commitment !== null && commitment !== void 0 ? commitment : (commitment = 'confirmed');
    const connection = new web3_js_1.Connection(amman_client_1.LOCALHOST, commitment);
    connection.onLogs('all', async (logs, _ctx) => {
        // only include transaction err for last line, otherwise we'd log it for each
        for (let i = 0; i < logs.logs.length; i++) {
            const line = logs.logs[i];
            try {
                await logLine(logger, line, null);
            }
            catch (err) {
                (0, utils_1.logTrace)('Logger encountered an error', err);
            }
        }
        if (logs.err != null) {
            await logLine(logger, '', logs.err);
        }
    }, commitment);
}
exports.pipeSolanaLogs = pipeSolanaLogs;
async function logLine(logger, line, error) {
    const { newLogs, newInstruction, newOuterInstruction } = await logger.addLine(line, error, programs_1.Cluster.Amman);
    if (newOuterInstruction) {
        console.log(ansi_colors_1.default.dim('\n--------------------------------'));
    }
    if (newInstruction) {
        console.log('');
    }
    for (const log of newLogs) {
        const color = styleToColor(log.style);
        const count = log.count != null
            ? ansi_colors_1.default.bgGreen(ansi_colors_1.default.black(`#${log.count.join('.')} `)) + ' '
            : '';
        console.log(`${ansi_colors_1.default.dim(log.prefix)}${count}${color(log.text)}`);
    }
}
function styleToColor(style) {
    switch (style) {
        case 'muted':
            return ansi_colors_1.default.dim;
        case 'info':
            return ansi_colors_1.default.white;
        case 'success':
            return ansi_colors_1.default.green;
        case 'warning':
            return ansi_colors_1.default.redBright;
        default:
            throw new Error(style);
    }
}
//# sourceMappingURL=solana-logs.js.map